@@ -1,11 +1,11 @@
-#' Simulate response patterns 
-#' 
+#' Simulate response patterns
+#'
 #' Simulates response patterns for compensatory and noncompensatory MIRT models
 #' from multivariate normally distributed factor (\eqn{\theta}) scores, or from
 #' a user input matrix of \eqn{\theta}'s.
-#' 
+#'
 #' Returns a data matrix simulated from the parameters.
-#' 
+#'
 #' @param a a matrix of slope parameters. If slopes are to be constrained to
 #' zero then use \code{NA}. \code{a} may also be a similar matrix specifying
 #' factor loadings if \code{factor.loads = TRUE}
@@ -13,17 +13,19 @@
 #' the item with the largest number of categories, and filled empty locations
 #' with \code{NA}
 #' @param itemtype a character vector of length \code{nrow(a)} (or 1, if all the item types are the same)
-#' specifying the type of items to simulate. 
-#' Can be \code{'dich', 'graded', 'gpcm','nominal'}, or \code{'partcomp'}, for 
-#' dichotomous, graded, generalized 
-#' partial credit, nominal, and partially compensatory models. Note that 
-#' for the gpcm and nominal model there should be as many parameters as desired categories,
-#' however to parameterized them for meaningful interpretation the first category intercept should 
-#' equal 0 for both models
+#' specifying the type of items to simulate.
+#' Can be \code{'dich', 'graded', 'gpcm','nominal', 'nestlogit'}, or \code{'partcomp'}, for
+#' dichotomous, graded, generalized
+#' partial credit, nominal, nested logit, and partially compensatory models. Note that
+#' for the gpcm, nominal, and nested logit models there should be as many parameters as desired categories,
+#' however to parametrized them for meaningful interpretation the first category intercept should
+#' equal 0 for these models (second column for \code{'nestlogit'}, since first column is for the
+#' correct item traceline). For nested logit models the 'correct' category is always the lowest category
+#' (i.e., == 1)
 #' @param nominal a matrix of specific item category slopes for nominal models.
 #' Should be the dimensions as the intercept specification with one less column, with \code{NA}
 #' in locations where not applicable. Note that during estimation the first slope will be constrained
-#' to 0 and the last will be constrained to the number of categories minus 1, 
+#' to 0 and the last will be constrained to the number of categories minus 1,
 #' so it is best to set these as the values for the first and last categories as well
 #' @param N sample size
 #' @param guess a vector of guessing parameters for each item; only applicable
@@ -31,7 +33,7 @@
 #' the dichotomous items, or a vector with as many values as to be simulated
 #' items
 #' @param upper same as \code{guess}, but for upper bound parameters
-#' @param D logistic scaling parameter, default 1.702
+#' @param D logistic scaling parameter, default is 1
 #' @param sigma a covariance matrix of the underlying distribution. Default is
 #' the identity matrix
 #' @param mu a mean vector of the underlying distribution. Default is a vector
@@ -44,9 +46,12 @@
 #' @keywords data
 #' @export simdata
 #' @examples
-#' 
+#'
 #' \dontrun{
 #' ###Parameters from Reckase (2009), p. 153
+#'
+#' set.seed(1234)
+#'
 #' a <- matrix(c(
 #'  .7471, .0250, .1428,
 #'  .4595, .0097, .0692,
@@ -77,20 +82,24 @@
 #'  .1341,1.4882, .0050,
 #'  .0524, .4754, .0012,
 #'  .2139, .4612, .0063,
-#'  .1761,1.1200, .0870),30,3,byrow=TRUE)
-#' 
+#'  .1761,1.1200, .0870),30,3,byrow=TRUE)*1.702
+#'
 #' d <- matrix(c(.1826,-.1924,-.4656,-.4336,-.4428,-.5845,-1.0403,
 #'   .6431,.0122,.0912,.8082,-.1867,.4533,-1.8398,.4139,
 #'   -.3004,-.1824,.5125,1.1342,.0230,.6172,-.1955,-.3668,
-#'   -1.7590,-.2434,.4925,-.3410,.2896,.006,.0329),ncol=1)
-#' 
+#'   -1.7590,-.2434,.4925,-.3410,.2896,.006,.0329),ncol=1)*1.702
+#'
 #' mu <- c(-.4, -.7, .1)
 #' sigma <- matrix(c(1.21,.297,1.232,.297,.81,.252,1.232,.252,1.96),3,3)
-#' 
+#'
 #' dataset1 <- simdata(a, d, 2000, itemtype = 'dich')
 #' dataset2 <- simdata(a, d, 2000, itemtype = 'dich', mu = mu, sigma = sigma)
-#' 
+#'
+#' #mod <- confmirt(dataset1, 3)
+#' #coef(mod)
+#'
 #' ###An example of a mixed item, bifactor loadings pattern with correlated specific factors
+#'
 #' a <- matrix(c(
 #' .8,.4,NA,
 #' .4,.4,NA,
@@ -98,25 +107,30 @@
 #' .8,NA,.4,
 #' .4,NA,.4,
 #' .7,NA,.4),ncol=3,byrow=TRUE)
-#' 
+#'
 #' d <- matrix(c(
 #' -1.0,NA,NA,
 #'  1.5,NA,NA,
 #'  0.0,NA,NA,
 #' 0.0,-1.0,1.5,  #the first 0 here is the recommended constraint for nominal
-#' 0.0,1.0,-1, #the first 0 here is the recommended constraint for gpcm 
+#' 0.0,1.0,-1, #the first 0 here is the recommended constraint for gpcm
 #' 2.0,0.0,NA),ncol=3,byrow=TRUE)
-#' 
+#'
 #' nominal <- matrix(NA, nrow(d), ncol(d))
-#' nominal[4, ] <- c(0,1.2,2) #the first 0 and last (ncat - 1) = 2 values are the recommended constraints
-#' 
+#' #the first 0 and last (ncat - 1) = 2 values are the recommended constraints
+#' nominal[4, ] <- c(0,1.2,2) 
+#'
 #' sigma <- diag(3)
 #' sigma[2,3] <- sigma[3,2] <- .25
 #' items <- c('dich','dich','dich','nominal','gpcm','graded')
-#' 
-#' dataset <- simdata(a,d,1000,items,sigma=sigma,nominal=nominal)
+#'
+#' dataset <- simdata(a,d,2000,items,sigma=sigma,nominal=nominal)
+#'
+#' #mod <- bfactor(dataset, c(1,1,1,2,2,2), itemtype = c(rep('2PL', 3), 'nominal', 'gpcm','graded'))
+#' #coef(mod)
 #'
 #' ####Unidimensional nonlinear factor pattern
+#'
 #' theta <- rnorm(2000)
 #' Theta <- cbind(theta,theta^2)
 #'
@@ -129,48 +143,88 @@
 #' .7,NA),ncol=2,byrow=TRUE)
 #' d <- matrix(rnorm(6))
 #' itemtype <- rep('dich',6)
-#' 
+#'
 #' nonlindata <- simdata(a,d,2000,itemtype,Theta=Theta)
 #'
+#' #model <- confmirt.model('
+#' #F1 = 1-6
+#' #(F1 * F1) = 1-3')
+#' #mod <- confmirt(nonlindata, model)
+#' #coef(mod)
+#'
+#' ####2PLNRM model for item 4 (with 4 categories), 2PL otherwise
+#'
+#' a <- matrix(rlnorm(4,0,.2))
+#'
+#' #first column of item 4 is the intercept for the correct category of 2PL model,
+#' #    otherwise nominal model configuration
+#' d <- matrix(c(
+#' -1.0,NA,NA,NA,
+#'  1.5,NA,NA,NA,
+#'  0.0,NA,NA,NA,
+#'  1, 0.0,-0.5,0.5),ncol=4,byrow=TRUE)
+#'
+#' nominal <- matrix(NA, nrow(d), ncol(d))
+#' nominal[4, ] <- c(NA,0,.5,.6)
+#'
+#' items <- c(rep('dich',3),'nestlogit')
+#'
+#' dataset <- simdata(a,d,2000,items,nominal=nominal)
+#'
+#' #mod <- mirt(dataset, 1, itemtype = c('2PL', '2PL', '2PL', '2PLNRM'), key=c(NA,NA,NA,1))
+#' #coef(mod)
+#' #itemplot(mod,4)
+#'
+#'
 #'    }
-#' 
-simdata <- function(a, d, N, itemtype, sigma = NULL, mu = NULL, guess = 0, 
-	upper = 1, nominal = NULL, Theta = NULL, D = 1.702)
-{       
-    fn <- function(p, ns) sample(1:ns, 1, prob = p)
+#'
+simdata <- function(a, d, N, itemtype, sigma = NULL, mu = NULL, guess = 0,
+	upper = 1, nominal = NULL, Theta = NULL, D = 1)
+{
+    fn <- function(p, ns) sample(1L:ns, 1, prob = p)
 	nfact <- ncol(a)
-	nitems <- nrow(a)		
-	K <- rep(0,nitems)	
-	if(length(guess) == 1) guess <- rep(guess,nitems)	
+	nitems <- nrow(a)
+	K <- rep(0,nitems)
+	if(length(guess) == 1L) guess <- rep(guess,nitems)
 	if(length(guess) != nitems) stop("Guessing parameter is incorrect")
-	if(length(upper) == 1) upper <- rep(upper,nitems)    
+	if(length(upper) == 1L) upper <- rep(upper,nitems)
 	if(length(upper) != nitems) stop("Upper bound parameter is incorrect")
-    if(length(itemtype) == 1) itemtype <- rep(itemtype, nitems)
-    for(i in 1:length(K)){
-        K[i] <- length(na.omit(d[i, ])) + 1
-        if(itemtype[i] =='partcomp') K[i] <- 2
-        if(any(itemtype[i] == c('gpcm', 'nominal'))) K[i] <- K[i] - 1
+    if(length(itemtype) == 1L) itemtype <- rep(itemtype, nitems)
+    for(i in 1L:length(K)){
+        K[i] <- length(na.omit(d[i, ])) + 1L
+        if(itemtype[i] =='partcomp') K[i] <- 2L
+        if(any(itemtype[i] == c('gpcm', 'nominal', 'nestlogit'))) K[i] <- K[i] - 1L
     }
-    guess[K > 2] <- upper[K > 2] <- NA	
+    K <- as.integer(K)
+    oldguess <- guess
+    oldupper <- upper
+    guess[K > 2L] <- upper[K > 2L] <- NA
+    guess[itemtype == 'nestlogit'] <- oldguess[itemtype == 'nestlogit']
+    upper[itemtype == 'nestlogit'] <- oldupper[itemtype == 'nestlogit']
 	if(is.null(sigma)) sigma <- diag(nfact)
 	if(is.null(mu)) mu <- rep(0,nfact)
 	if(!is.null(Theta))
-		if(ncol(Theta) != nfact || nrow(Theta) != N) 
+		if(ncol(Theta) != nfact || nrow(Theta) != N)
 			stop("The input Theta matrix does not have the correct dimensions")
-	if(is.null(Theta)) Theta <- mvtnorm::rmvnorm(N,mu,sigma)     
+	if(is.null(Theta)) Theta <- mvtnorm::rmvnorm(N,mu,sigma)
     if(is.null(nominal)) nominal <- matrix(NA, nitems, 1)
-	data <- matrix(0, N, nitems)	
-    a[is.na(a)] <- 0    
-	for(i in 1:nitems){
-        par <- na.omit(c(a[i, ],nominal[i,],d[i,],guess[i],upper[i]))
-        obj <- new(itemtype[i], par=par, nfact=nfact, D=D)
-        if(any(itemtype[i] == c('gpcm','nominal'))) 
+	data <- matrix(0, N, nitems)
+    a[is.na(a)] <- 0
+	for(i in 1L:nitems){
+	    if(itemtype[i] == 'nestlogit'){
+	        par <- na.omit(c(a[i, ],d[i,1], guess[i], upper[i], nominal[i,-1L],d[i,-1L]))
+	        obj <- new(itemtype[i], par=par, nfact=nfact, D=D, correctcat=1L)
+	    } else {
+            par <- na.omit(c(a[i, ],nominal[i,],d[i,],guess[i],upper[i]))
+            obj <- new(itemtype[i], par=par, nfact=nfact, D=D)
+	    }
+        if(any(itemtype[i] == c('gpcm','nominal', 'nestlogit')))
             obj@ncat <- K[i]
         P <- ProbTrace(obj, Theta)
-        data[,i] <- apply(P, 1, fn, ns = ncol(P))		                   
-        if(any(itemtype[i] == c('dich', 'gpcm', 'partcomp'))) data[ ,i] <- data[ ,i] - 1 
+        data[,i] <- apply(P, 1, fn, ns = ncol(P))
+        if(any(itemtype[i] == c('dich', 'gpcm', 'partcomp'))) data[ ,i] <- data[ ,i] - 1L
 	}
-	colnames(data) <- paste("Item_", 1:nitems, sep="") 
+	colnames(data) <- paste("Item_", 1L:nitems, sep="")
 	return(data)
 }
 
